---
title: <span class="badge object-type-scalar"></span> GUnit
---
# <span class="badge object-type-scalar"></span> GUnit

G unit (g)

## Definition

```python
# G unit (g)
GUnit: typing.Literal["accG"] = "accG"
```
